==> 1.13.0.tar.gz: lib/src/core/helpers/share/mobile/implementation.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:path_provider/path_provider.dart';
import 'package:share_plus/share_plus.dart';

class ShareHelperImplementation {
  static Future<void> text(
    String text, {
    String? subject,
    Rect? sharePositionOrigin,
  }) async {
    await Share.share(
      text,
      subject: subject,
      sharePositionOrigin: sharePositionOrigin ?? _getSharePositionOrigin(),
    );
  }

  static Future<void> file(
      String title, String name, List<int> bytes, String mimeType,
      {String text = ''}) async {
    String path = await _getPath(bytes, name);

    await Share.shareFiles(
      [path],
      mimeTypes: [mimeType],
      text: text,
      subject: title,
      sharePositionOrigin: _getSharePositionOrigin(),
    );
  }

  static Future<void> files(
      String title, Map<String, List<int>> files, String mimeType,
      {String text = ''}) async {
    List<String> paths = [];

    Future<void> task(List<int> bytes, String name) async {
      String path = await _getPath(bytes, name);
      paths.add(path);
    }

    List<Future> futures = [];

    files.forEach((key, value) {
      futures.add(task(value, key));
    });

    await Future.wait(futures);

    await Share.shareFiles(
      paths,
      mimeTypes: [mimeType],
      text: text,
      subject: title,
      sharePositionOrigin: _getSharePositionOrigin(),
    );
  }

  static Rect? _getSharePositionOrigin() {
    return Rect.fromLTWH(
        0, 0, ScreenUtil().screenWidth, ScreenUtil().screenHeight / 2);
    // try {
    //   final box =
    //       ModernFormGlobalContext.context?.findRenderObject() as RenderBox?;
    //   return box!.localToGlobal(Offset.zero) & box.size;
    // } catch (e) {
    //   print(
    //       "ERROR ShareHelperImplementation mobile _getSharePositionOrigin() --> $e");
    //   return null;
    // }
  }

  static Future<String> _getPath(
    List<int> bytes,
    String name,
  ) async {
    final tempDir = await getTemporaryDirectory();
    String path =
        '${tempDir.path}/${DateTime.now().millisecondsSinceEpoch}$name';
    final file = await new File(path).create();
    await file.writeAsBytes(bytes);

    return path;
  }
}

==> 1.23.0.tar.gz: lib/src/core/helpers/share/mobile/implementation.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:path_provider/path_provider.dart';
import 'package:share_plus/share_plus.dart';

class ShareHelperImplementation {
  static Future<void> text(
    String text, {
    String? subject,
    Rect? sharePositionOrigin,
  }) async {
    await Share.share(
      text,
      subject: subject,
      sharePositionOrigin: sharePositionOrigin ?? _getSharePositionOrigin(),
    );
  }

  static Future<void> file(
      String title, String name, List<int> bytes, String mimeType,
      {String text = ''}) async {
    String path = await _getPath(bytes, name);

    await Share.shareFiles(
      [path],
      mimeTypes: [mimeType],
      text: text,
      subject: title,
      sharePositionOrigin: _getSharePositionOrigin(),
    );
  }

  static Future<void> files(
      String title, Map<String, List<int>> files, String mimeType,
      {String text = ''}) async {
    List<String> paths = [];

    Future<void> task(List<int> bytes, String name) async {
      String path = await _getPath(bytes, name);
      paths.add(path);
    }

    List<Future> futures = [];

    files.forEach((key, value) {
      futures.add(task(value, key));
    });

    await Future.wait(futures);

    await Share.shareFiles(
      paths,
      mimeTypes: [mimeType],
      text: text,
      subject: title,
      sharePositionOrigin: _getSharePositionOrigin(),
    );
  }

  static Rect? _getSharePositionOrigin() {
    return Rect.fromLTWH(
        0, 0, ScreenUtil().screenWidth, ScreenUtil().screenHeight / 2);
    // try {
    //   final box =
    //       ModernFormGlobalContext.context?.findRenderObject() as RenderBox?;
    //   return box!.localToGlobal(Offset.zero) & box.size;
    // } catch (e) {
    //   print(
    //       "ERROR ShareHelperImplementation mobile _getSharePositionOrigin() --> $e");
    //   return null;
    // }
  }

  static Future<String> _getPath(
    List<int> bytes,
    String name,
  ) async {
    final tempDir = await getTemporaryDirectory();
    String path =
        '${tempDir.path}/${DateTime.now().microsecondsSinceEpoch}$name';
    final file = await File(path).create(recursive: true);
    await file.writeAsBytes(bytes);

    return path;
  }
}
